=====
pytsp
=====


.. image:: https://img.shields.io/pypi/v/pytsp.svg
        :target: https://pypi.python.org/pypi/pytsp

.. image:: https://img.shields.io/travis/BraveDistribution/pytsp.svg
        :target: https://travis-ci.org/BraveDistribution/pytsp

.. image:: https://readthedocs.org/projects/pytsp/badge/?version=latest
        :target: https://pytsp.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Few algorithms for TSP problem in Python


* Free software: MIT license
* Documentation: https://pytsp.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
